@@ -3,7 +3,7 @@ class Handler_Public extends Handler {
 
 	private function generate_syndicated_feed($owner_uid, $feed, $is_cat,
 		$limit, $offset, $search, $search_mode,
-		$view_mode = false, $format = 'atom', $order = false, $orig_guid = false) {
+		$view_mode = false, $format = 'atom', $order = false, $orig_guid = false, $start_ts = false) {
 
 		require_once "lib/MiniTemplator.class.php";
 
@@ -37,10 +37,13 @@ class Handler_Public extends Handler {
 			break;
 		}
 
+		//function queryFeedHeadlines($feed, $limit, $view_mode, $cat_view, $search, $search_mode, $override_order = false, $offset = 0, $owner_uid = 0, $filter = false, $since_id = 0, $include_children = false, $ignore_vfeed_group = false, $override_strategy = false, $override_vfeed = false, $start_ts = false) {
+
+
 		$qfh_ret = queryFeedHeadlines($feed,
 			1, $view_mode, $is_cat, $search, $search_mode,
 			$date_sort_field, $offset, $owner_uid,
-			false, 0, false, true);
+			false, 0, false, true, false, false, $start_ts);
 
 		$result = $qfh_ret[0];
 
@@ -61,13 +64,13 @@ class Handler_Public extends Handler {
 		$qfh_ret = queryFeedHeadlines($feed,
 			$limit, $view_mode, $is_cat, $search, $search_mode,
 			$date_sort_field, $offset, $owner_uid,
-			false, 0, false, true);
+			false, 0, false, true, false, false, $start_ts);
 
 
 		$result = $qfh_ret[0];
 		$feed_title = htmlspecialchars($qfh_ret[1]);
 		$feed_site_url = $qfh_ret[2];
-		$last_error = $qfh_ret[3];
+		/* $last_error = $qfh_ret[3]; */
 
 		$feed_self_url = get_self_url_prefix() .
 			"/public.php?op=rss&id=$feed&key=" .
@@ -105,7 +108,8 @@ class Handler_Public extends Handler {
 				$tpl->setVariable('ARTICLE_TITLE', htmlspecialchars($line['title']), true);
 				$tpl->setVariable('ARTICLE_EXCERPT', $line["content_preview"], true);
 
-				$content = sanitize($line["content"], false, $owner_uid);
+				$content = sanitize($line["content"], false, $owner_uid,
+					$feed_site_url);
 
 				if ($line['note']) {
 					$content = "<div style=\"$note_style\">Article note: " . $line['note'] . "</div>" .
@@ -375,6 +379,7 @@ class Handler_Public extends Handler {
 		$search_mode = $this->dbh->escape_string($_REQUEST["smode"]);
 		$view_mode = $this->dbh->escape_string($_REQUEST["view-mode"]);
 		$order = $this->dbh->escape_string($_REQUEST["order"]);
+		$start_ts = $this->dbh->escape_string($_REQUEST["ts"]);
 
 		$format = $this->dbh->escape_string($_REQUEST['format']);
 		$orig_guid = sql_bool_to_bool($_REQUEST["orig_guid"]);
@@ -397,24 +402,24 @@ class Handler_Public extends Handler {
 
 		if ($owner_id) {
 			$this->generate_syndicated_feed($owner_id, $feed, $is_cat, $limit,
-				$offset, $search, $search_mode, $view_mode, $format, $order, $orig_guid);
+				$offset, $search, $search_mode, $view_mode, $format, $order, $orig_guid, $start_ts);
 		} else {
 			header('HTTP/1.1 403 Forbidden');
 		}
 	}
 
 	function updateTask() {
-		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_UPDATE_TASK, "hook_update_task", $op);
+		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_UPDATE_TASK, "hook_update_task", false);
 	}
 
 	function housekeepingTask() {
-		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_HOUSE_KEEPING, "hook_house_keeping", $op);
+		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_HOUSE_KEEPING, "hook_house_keeping", false);
 	}
 
 	function globalUpdateFeeds() {
 		RPC::updaterandomfeed_real($this->dbh);
 
-		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_UPDATE_TASK, "hook_update_task", $op);
+		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_UPDATE_TASK, "hook_update_task", false);
 	}
 
 	function sharepopup() {
@@ -427,9 +432,10 @@ class Handler_Public extends Handler {
 		<link rel=\"shortcut icon\" type=\"image/png\" href=\"images/favicon.png\">
 		<link rel=\"icon\" type=\"image/png\" sizes=\"72x72\" href=\"images/favicon-72px.png\">";
 
-		stylesheet_tag("css/utility.css");
-		javascript_tag("lib/prototype.js");
-		javascript_tag("lib/scriptaculous/scriptaculous.js?load=effects,dragdrop,controls");
+		echo stylesheet_tag("css/utility.css");
+		echo stylesheet_tag("css/dijit.css");
+		echo javascript_tag("lib/prototype.js");
+		echo javascript_tag("lib/scriptaculous/scriptaculous.js?load=effects,controls");
 		print "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"/>
 			</head><body id='sharepopup'>";
 
@@ -575,7 +581,7 @@ class Handler_Public extends Handler {
 				}
 			} else {
 				$_SESSION["login_error_msg"] = __("Incorrect username or password");
-				user_error("Failed login attempt from {$_SERVER['REMOTE_ADDR']}", E_USER_WARNING);
+				user_error("Failed login attempt for $login from {$_SERVER['REMOTE_ADDR']}", E_USER_WARNING);
 			}
 
 			if ($_REQUEST['return']) {
@@ -586,6 +592,18 @@ class Handler_Public extends Handler {
 		}
 	}
 
+	/* function subtest() {
+		header("Content-type: text/plain; charset=utf-8");
+
+		$url = $_REQUEST["url"];
+
+		print "$url\n\n";
+
+
+		print_r(get_feeds_from_html($url, fetch_file_contents($url)));
+
+	} */
+
 	function subscribe() {
 		if (SINGLE_USER_MODE) {
 			login_sequence();
@@ -688,93 +706,6 @@ class Handler_Public extends Handler {
 		}
 	}
 
-	function subscribe2() {
-		$feed_url = $this->dbh->escape_string(trim($_REQUEST["feed_url"]));
-		$cat_id = $this->dbh->escape_string($_REQUEST["cat_id"]);
-		$from = $this->dbh->escape_string($_REQUEST["from"]);
-		$feed_urls = array();
-
-		/* only read authentication information from POST */
-
-		$auth_login = $this->dbh->escape_string(trim($_POST["auth_login"]));
-		$auth_pass = $this->dbh->escape_string(trim($_POST["auth_pass"]));
-
-		$rc = subscribe_to_feed($feed_url, $cat_id, $auth_login, $auth_pass);
-
-		switch ($rc) {
-		case 1:
-			print_notice(T_sprintf("Subscribed to <b>%s</b>.", $feed_url));
-			break;
-		case 2:
-			print_error(T_sprintf("Could not subscribe to <b>%s</b>.", $feed_url));
-			break;
-		case 3:
-			print_error(T_sprintf("No feeds found in <b>%s</b>.", $feed_url));
-			break;
-		case 0:
-			print_warning(T_sprintf("Already subscribed to <b>%s</b>.", $feed_url));
-			break;
-		case 4:
-			print_notice(__("Multiple feed URLs found."));
- 			$contents = @fetch_file_contents($url, false, $auth_login, $auth_pass);
-			if (is_html($contents)) {
-				$feed_urls = get_feeds_from_html($url, $contents);
-			}
-			break;
-		case 5:
-			print_error(T_sprintf("Could not subscribe to <b>%s</b>.<br>Can't download the Feed URL.", $feed_url));
-			break;
-		}
-
-		if ($feed_urls) {
-			print "<form action=\"backend.php\">";
-			print "<input type=\"hidden\" name=\"op\" value=\"pref-feeds\">";
-			print "<input type=\"hidden\" name=\"quiet\" value=\"1\">";
-			print "<input type=\"hidden\" name=\"method\" value=\"add\">";
-
-			print "<select name=\"feed_url\">";
-
-			foreach ($feed_urls as $url => $name) {
-				$url = htmlspecialchars($url);
-				$name = htmlspecialchars($name);
-				print "<option value=\"$url\">$name</option>";
-			}
-
-			print "<input type=\"submit\" value=\"".__("Subscribe to selected feed")."\">";
-			print "</form>";
-		}
-
-		$tp_uri = get_self_url_prefix() . "/prefs.php";
-		$tt_uri = get_self_url_prefix();
-
-		if ($rc <= 2){
-			$result = $this->dbh->query("SELECT id FROM ttrss_feeds WHERE
-				feed_url = '$feed_url' AND owner_uid = " . $_SESSION["uid"]);
-
-			$feed_id = $this->dbh->fetch_result($result, 0, "id");
-		} else {
-			$feed_id = 0;
-		}
-
-		print "<p>";
-
-		if ($feed_id) {
-			print "<form method=\"GET\" style='display: inline'
-				action=\"$tp_uri\">
-				<input type=\"hidden\" name=\"tab\" value=\"feedConfig\">
-				<input type=\"hidden\" name=\"method\" value=\"editFeed\">
-				<input type=\"hidden\" name=\"methodparam\" value=\"$feed_id\">
-				<input type=\"submit\" value=\"".__("Edit subscription options")."\">
-				</form>";
-		}
-
-		print "<form style='display: inline' method=\"GET\" action=\"$tt_uri\">
-			<input type=\"submit\" value=\"".__("Return to Tiny Tiny RSS")."\">
-			</form></p>";
-
-		print "</body></html>";
-	}
-
 	function index() {
 		header("Content-Type: text/plain");
 		print json_encode(array("error" => array("code" => 7)));
@@ -783,13 +714,15 @@ class Handler_Public extends Handler {
 	function forgotpass() {
 		startup_gettext();
 
+		@$hash = $_REQUEST["hash"];
+
 		header('Content-Type: text/html; charset=utf-8');
 		print "<html><head><title>Tiny Tiny RSS</title>
 		<link rel=\"shortcut icon\" type=\"image/png\" href=\"images/favicon.png\">
 		<link rel=\"icon\" type=\"image/png\" sizes=\"72x72\" href=\"images/favicon-72px.png\">";
 
-		stylesheet_tag("css/utility.css");
-		javascript_tag("lib/prototype.js");
+		echo stylesheet_tag("css/utility.css");
+		echo javascript_tag("lib/prototype.js");
 
 		print "<meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"/>
 			</head><body id='forgotpass'>";
@@ -800,8 +733,45 @@ class Handler_Public extends Handler {
 
 		@$method = $_POST['method'];
 
-		if (!$method) {
-			print_notice(__("You will need to provide valid account name and email. New password will be sent on your email address."));
+		if ($hash) {
+			$login = $_REQUEST["login"];
+
+			if ($login) {
+				$result = $this->dbh->query("SELECT id, resetpass_token FROM ttrss_users
+					WHERE login = '$login'");
+
+				if ($this->dbh->num_rows($result) != 0) {
+					$id = $this->dbh->fetch_result($result, 0, "id");
+					$resetpass_token_full = $this->dbh->fetch_result($result, 0, "resetpass_token");
+					list($timestamp, $resetpass_token) = explode(":", $resetpass_token_full);
+
+					if ($timestamp && $resetpass_token &&
+						$timestamp >= time() - 15*60*60 &&
+						$resetpass_token == $hash) {
+
+							$result = $this->dbh->query("UPDATE ttrss_users SET resetpass_token = NULL
+								WHERE id = $id");
+
+							Pref_Users::resetUserPassword($id, true);
+
+							print "<p>"."Completed."."</p>";
+
+					} else {
+						print_error("Some of the information provided is missing or incorrect.");
+					}
+				} else {
+					print_error("Some of the information provided is missing or incorrect.");
+				}
+			} else {
+				print_error("Some of the information provided is missing or incorrect.");
+			}
+
+			print "<form method=\"GET\" action=\"index.php\">
+				<input type=\"submit\" value=\"".__("Return to Tiny Tiny RSS")."\">
+				</form>";
+
+		} else if (!$method) {
+			print_notice(__("You will need to provide valid account name and email. A password reset link will be sent to your email address."));
 
 			print "<form method='POST' action='public.php'>";
 			print "<input type='hidden' name='method' value='do'>";
@@ -842,17 +812,57 @@ class Handler_Public extends Handler {
 
 			} else {
 
+				print_notice("Password reset instructions are being sent to your email address.");
+
 				$result = $this->dbh->query("SELECT id FROM ttrss_users
 					WHERE login = '$login' AND email = '$email'");
 
 				if ($this->dbh->num_rows($result) != 0) {
 					$id = $this->dbh->fetch_result($result, 0, "id");
 
-					Pref_Users::resetUserPassword($id, false);
+					if ($id) {
+						$resetpass_token = sha1(get_random_bytes(128));
+						$resetpass_link = get_self_url_prefix() . "/public.php?op=forgotpass&hash=" . $resetpass_token .
+							"&login=" . urlencode($login);
 
-					print "<p>";
+						require_once 'classes/ttrssmailer.php';
+						require_once "lib/MiniTemplator.class.php";
 
-					print "<p>"."Completed."."</p>";
+						$tpl = new MiniTemplator;
+
+						$tpl->readTemplateFromFile("templates/resetpass_link_template.txt");
+
+						$tpl->setVariable('LOGIN', $login);
+						$tpl->setVariable('RESETPASS_LINK', $resetpass_link);
+
+						$tpl->addBlock('message');
+
+						$message = "";
+
+						$tpl->generateOutputToString($message);
+
+						$mail = new ttrssMailer();
+
+						$rc = $mail->quickMail($email, $login,
+							__("[tt-rss] Password reset request"),
+							$message, false);
+
+						if (!$rc) print_error($mail->ErrorInfo);
+
+						$resetpass_token_full = $this->dbh->escape_string(time() . ":" . $resetpass_token);
+
+						$result = $this->dbh->query("UPDATE ttrss_users
+							SET resetpass_token = '$resetpass_token_full'
+							WHERE login = '$login' AND email = '$email'");
+
+						//Pref_Users::resetUserPassword($id, false);
+
+						print "<p>";
+
+						print "<p>"."Completed."."</p>";
+					} else {
+						print_error("User ID not found.");
+					}
 
 					print "<form method=\"GET\" action=\"index.php\">
 						<input type=\"submit\" value=\"".__("Return to Tiny Tiny RSS")."\">
