@@ -39,6 +39,9 @@ class PluginHost {
 	const HOOK_FETCH_FEED = 22;
 	const HOOK_QUERY_HEADLINES = 23;
 	const HOOK_HOUSE_KEEPING = 24;
+	const HOOK_SEARCH = 25;
+	const HOOK_FORMAT_ENCLOSURES = 26;
+	const HOOK_SUBSCRIBE_FEED = 27;
 
 	const KIND_ALL = 1;
 	const KIND_SYSTEM = 2;
@@ -75,6 +78,16 @@ class PluginHost {
 		return $this->dbh;
 	}
 
+	function get_plugin_names() {
+		$names = array();
+
+		foreach ($this->plugins as $p) {
+			array_push($names, get_class($p));
+		}
+
+		return $names;
+	}
+
 	function get_plugins() {
 		return $this->plugins;
 	}
@@ -99,7 +112,7 @@ class PluginHost {
 
 	function del_hook($type, $sender) {
 		if (is_array($this->hooks[$type])) {
-			$key = array_Search($this->hooks[$type], $sender);
+			$key = array_Search($sender, $this->hooks[$type]);
 			if ($key !== FALSE) {
 				unset($this->hooks[$type][$key]);
 			}
